@@ -1,3 +1,8 @@
+"""
+The Exceptions File
+"""
+
+
 class InvalidInfo(Exception):
     """
     Raised when the username or password is invalid
@@ -45,3 +50,9 @@ class InvalidForumTopic(Exception):
     Raised when the forum topic is invalid
     """
     pass
+
+
+class ForbiddenLogin(Exception):
+    """
+    Raised when Scratch sends a 403 Forbidden Status Code while logging in
+    """
